@@ -3,7 +3,7 @@
  * Horde_Share_Sqlng provides the next-generation SQL backend driver for the
  * Horde_Share library.
  *
- * Copyright 2011-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -139,6 +139,31 @@ class Horde_Share_Sqlng extends Horde_Share_Sql
         return $this->_listcache[$key];
     }
 
+    /**
+     * Returns an array of all system shares.
+     *
+     * @return array  All system shares.
+     * @throws Horde_Share_Exception
+     */
+    public function listSystemShares()
+    {
+        $query = 'SELECT * FROM ' . $this->_table . ' WHERE share_owner IS NULL';
+        try {
+            $rows = $this->_db->selectAll($query);
+        } catch (Horde_Db_Exception $e) {
+            throw new Horde_Share_Exception($e->getMessage());
+        }
+
+        $sharelist = array();
+        foreach ($rows as $share) {
+            $data = $this->_fromDriverCharset($share);
+            $this->_loadPermissions($data);
+            $sharelist[$data['share_name']] = $this->_createObject($data);
+        }
+
+        return $sharelist;
+    }
+
     /**
      * Returns the count of all shares that $userid has access to.
      *
@@ -252,7 +277,7 @@ class Horde_Share_Sqlng extends Horde_Share_Sql
      *
      * @return array  The bit mask as an array.
      */
-    static public function convertBitmaskToArray($perm)
+    public static function convertBitmaskToArray($perm)
     {
         $perms = array();
         for ($bit = 1; $perm; $bit *= 2, $perm >>= 1) {
@@ -398,7 +423,7 @@ class Horde_Share_Sqlng extends Horde_Share_Sql
             // (name == perm_creator and val & $perm)
             $where .= ' OR ' . $this->_getPermsCriteria('perm_creator', $perms);
 
-            // (name == perm_creator and val & $perm)
+            // (name == perm_default and val & $perm)
             $where .= ' OR ' . $this->_getPermsCriteria('perm_default', $perms);
 
             if ($shareids) {
